### Name: gmm
### Title: Generalized method of moment estimation
### Aliases: gmm


### ** Examples

# First, an exemple with the fonction g()

g <- function(tet,x)
        {
        n <- nrow(x)
        u <- (x[7:n] - tet[1] - tet[2]*x[6:(n-1)] - tet[3]*x[5:(n-2)])
        f <- cbind(u,u*x[4:(n-3)],u*x[3:(n-4)],u*x[2:(n-5)],u*x[1:(n-6)])
        return(f)
        }

Dg <- function(tet,x)
        {
        n <- nrow(x)
        xx <- cbind(rep(1,(n-6)),x[6:(n-1)],x[5:(n-2)])
        H  <- cbind(rep(1,(n-6)),x[4:(n-3)],x[3:(n-4)],x[2:(n-5)],x[1:(n-6)])
        f <- -crossprod(H,xx)/(n-6)
        return(f)
        }
n = 500
set.seed(123)
phi<-c(.2,.7)
thet <- 0.2
sd <- .2
x <- matrix(arima.sim(n=n,list(order=c(2,0,1),ar=phi,ma=thet,sd=sd)),ncol=1)

res_2s <- gmm(g,x,c(0,.3,.6),gradv=Dg)
summary(res_2s)

res_iter <- gmm(g,x,c(0,.3,.6),gradv=Dg,type="iterative")
summary(res_iter)

# The same model but with g as a formula....  much simpler in that case

y <- x[7:n]
ym1 <- x[6:(n-1)]
ym2 <- x[5:(n-2)]

H <- cbind(x[4:(n-3)],x[3:(n-4)],x[2:(n-5)],x[1:(n-6)])
g <- y~ym1+ym2
x <- H

res_2s <- gmm(g,x)
summary(res_2s)

res_iter <- gmm(g,x,type="iterative")
summary(res_iter)

## The following example has been provided by Dieter Rozenich (see details).
# It generates normal random numbers and uses the GMM to estimate 
# mean and sd.
#-------------------------------------------------------------------------------
# Random numbers of a normal distribution
# First we generate normally distributed random numbers and compute the two parameters:
n <- 1000
x <- rnorm(n, mean = 4, sd = 2)
# Implementing the 3 moment conditions
g <- function(tet,x)
        {
        m1 <- (tet[1]-x)
        m2 <- (tet[2]^2 - (x - tet[1])^2)
        m3 <- x^3-tet[1]*(tet[1]^2+3*tet[2]^2)
        f <- cbind(m1,m2,m3)
        return(f)
        }
# Implementing the jacobian
Dg <- function(tet,x)
        {
        jacobian <- matrix(c( 1, 2*(-tet[1]+mean(x)), -3*tet[1]^2-3*tet[2]^2,0, 2*tet[2],-6*tet[1]*tet[2]), nrow=3,ncol=2)
        return(jacobian)
        }
# Now we want to estimate the two parameters using the GMM.
require(gmm)
resgmm <- gmm(g,x,c(0,0),grad=Dg)



