###################################################
### chunk number 1: 
###################################################
require(gmm)


###################################################
### chunk number 2: 
###################################################
set.seed(123)
n <- 1000
x1 <- rnorm(n, mean = 4, sd = 2)
mean(x1)
sd(x1)


###################################################
### chunk number 3: 
###################################################
g <- function(tet,x)
        {
        m1 <- (tet[1]-x)
        m2 <- (tet[2]^2 - (x - tet[1])^2)
        m3 <- x^3-tet[1]*(tet[1]^2+3*tet[2]^2)
        f <- cbind(m1,m2,m3)
        return(f)
        }


###################################################
### chunk number 4: 
###################################################
res <- gmm(g,x1,c(0,0))
res$par


###################################################
### chunk number 5: 
###################################################
Dg <- function(tet,x)
        {
        jacobian <- matrix(c( 1,
                              2*(-tet[1]+mean(x)),
                              -3*tet[1]^2-3*tet[2]^2,0,
                              2*tet[2],-6*tet[1]*tet[2]),
                           nrow=3,ncol=2)
        return(jacobian)
        }


###################################################
### chunk number 6: 
###################################################
res2 <- gmm(g,x1,c(0,0),grad=Dg)
res2$par


###################################################
### chunk number 7: 
###################################################
summary(res)$par
summary(res2)$par


###################################################
### chunk number 8: 
###################################################
require(mvtnorm)
sig <- matrix(c(1,.5,.5,1),2,2)
t <- 500
e <- rmvnorm(t,sigma=sig)
x2 <- rnorm(t)
w <- exp(-x2^2) + e[,1]
y <- 0.1*w + e[,2]


###################################################
### chunk number 9: 
###################################################
h <- cbind(x2, x2^2, x2^3)
fct <- y~w


###################################################
### chunk number 10: 
###################################################
res <- gmm(fct,x=h)
summary(res)


###################################################
### chunk number 11: 
###################################################
res2 <- gmm(fct,x=h,type='iterative')
summary(res2)$par
summary(res2)$j


###################################################
### chunk number 12: 
###################################################
res3 <- gmm(fct,x=h,res2$par,type='cue')
summary(res3)$par
summary(res3)$j


###################################################
### chunk number 13: 
###################################################
summary(res3,interval=0.95)$interval


###################################################
### chunk number 14: 
###################################################
R <- diag(2)
c <- matrix(c(0,.1),2,1)
lintest(res3,R,c)


###################################################
### chunk number 15: 
###################################################
t <- 400
x3 <- arima.sim(n=t,list(ar=c(1.4,-0.6),ma=c(0.6,-0.3)))
xt <- x3[7:t]
xt1 <- x3[6:(t-1)]
xt2 <- x3[5:(t-2)]
h2 <- cbind(x3[4:(t-3)],x3[3:(t-4)],x3[2:(t-5)],x3[1:(t-6)])
fct2 <- xt~xt1+xt2
res <- gmm(fct2,x=h2)
summary(res)$par
summary(res)$j


###################################################
### chunk number 16: 
###################################################
x3 <- matrix(x3,400,1)
HAC(x3)


###################################################
### chunk number 17: 
###################################################
HAC(x3,kernel="Truncated")
HAC(x3,kernel="Bartlett")
HAC(x3,kernel="Parzen")
HAC(x3,kernel="Tukey-Hanning")


###################################################
### chunk number 18: 
###################################################
res <- gmm(fct2,x=h2,kernel="Bartlett",prewhite=1,bw=bwNeweyWest2,type="iterative")
summary(res)$par


###################################################
### chunk number 19: 
###################################################
data(Finance)
r <- Finance$r
rf <- Finance$rf
rm <- Finance$rm
z <- r-rf
t <- nrow(z)
zm <- matrix(rm-rf,t,1)
res <- gmm(z~zm,x=zm)
summary(res)$par
R <- cbind(diag(10),matrix(0,10,10))
c <- matrix(0,10,1)
lintest(res,R,c)


###################################################
### chunk number 20: 
###################################################
res_el <- gel(g,x1,c(mean(x1),sd(x1)))
sres_el <- summary(res_el)
sres_el$par
sres_el$lambda
sres_el$test


###################################################
### chunk number 21: 
###################################################
res_et <- gel(g,x1,c(mean(x1),sd(x1)),type="ET")
summary(res_et)$par


###################################################
### chunk number 22: 
###################################################
res_cue <- gel(g,x1,c(mean(x1),sd(x1)),type="CUE")
summary(res_cue)$par


###################################################
### chunk number 23: 
###################################################
system.time(gel(g,x1,c(mean(x1),sd(x1))))
system.time(gel(g,x1,c(mean(x1),sd(x1)),type="ET"))
system.time(gel(g,x1,c(mean(x1),sd(x1)),type="CUE"))


###################################################
### chunk number 24: 
###################################################
names(summary(res_el))


###################################################
### chunk number 25: 
###################################################
summary(res_el)$badrho


###################################################
### chunk number 26: 
###################################################
summary(res_el)$conv_lamb


###################################################
### chunk number 27: 
###################################################
summary(res_el)$conv_par
summary(res_el)$conv_moment
summary(res_el)$conv_pt


###################################################
### chunk number 28: 
###################################################
res <- gel(g,x1,c(mean(x1),sd(x1)),type="ETEL")
summary(res)$par
system.time(gel(g,x1,c(mean(x1),sd(x1)),type="ETEL"))


###################################################
### chunk number 29: 
###################################################
tet0 <- gmm(fct,x=h,wmatrix="ident")$par
res <- gel(fct,x=h,tet0)
summary(res)


###################################################
### chunk number 30: 
###################################################
R <- matrix(c(0,1),1,2)
c <- 0.1
lintest(res,R,c)


###################################################
### chunk number 31: 
###################################################
tet0 <- gmm(fct2,x=h2,wmatrix="ident")$par
res <- gel(fct2,x=h2,tet0,smooth=TRUE,kernel="Truncated")
summary(res)


